imodels.util API documentation
Description: Shared utilities for implementing different interpretable models.

# Module `imodels.util`

Shared utilities for implementing different interpretable models.

Expand source code

    '''Shared utilities for implementing different interpretable models.
    '''

## Sub-modules

`imodels.util.checks`
`imodels.util.convert`
`imodels.util.data_util`
`imodels.util.explain_errors`
`imodels.util.extract`
`imodels.util.metrics`
`imodels.util.neural_nets`

  Bridging random forests and deep neural networks. Code to convert a sklearn decision tree to a pytorch neural network following "Neural Random …

`imodels.util.prune`
`imodels.util.rule`
`imodels.util.score`
`imodels.util.transforms`

  Shared transforms between different interpretable models

`imodels.util.tree`